==> lib_common_fx-0.0.2.tar.gz: lib/utils/toolbar.dart <==
import 'package:flutter/material.dart';

import 'fx_colors.dart';
import 'fx_text.dart';

class Toolbar extends AppBar {
  final String titleStr;
  final bool showBack;
  final double height;
  final List<Widget> actions;
  final PreferredSizeWidget? bottom;
  final Function? backButtonAction;
  final Color? backgroundColor;
  final Color? titleColor;
  final int fontWeightDelta;

  Toolbar(
      {Key? key,
      this.titleStr = '',
      this.height = 48,
      this.showBack = true,
      this.bottom,
      this.actions = const [],
      this.backButtonAction = null,
      this.backgroundColor = FXColor.main_white,
      this.fontWeightDelta = 0,
      this.titleColor = FXColor.main_black1})
      : super(
            key: key,
            centerTitle: true,
            toolbarHeight: height,
            elevation: 0,
            backgroundColor: backgroundColor,
            title:
                FXText(titleStr, style: FXText.title_black.apply(color: titleColor, fontWeightDelta: fontWeightDelta)),
            actions: actions,
            leading: showBack
                ? Builder(builder: (context) {
                    return IconButton(
                        splashColor: Colors.transparent,
                        highlightColor: Colors.transparent,
                        padding: const EdgeInsets.all(6),
                        icon: const ImageIcon(AssetImage('images/icon_back.png'), color: FXColor.black),
                        onPressed: () {
                          backButtonAction?.call();
                          Navigator.maybePop(context);
                        });
                  })
                : null,
            bottom: bottom);
}

==> lib_common_fx-0.0.17.tar.gz: lib/utils/toolbar.dart <==
import 'package:flutter/material.dart';
import 'package:lib_common_fx/lib_common_fx.dart';

import 'fx_colors.dart';
import 'fx_text.dart';
import 'image_utils.dart';

class Toolbar extends AppBar {
  final String titleStr;
  final bool showBack;
  final double height;
  final List<Widget> actions;
  final PreferredSizeWidget? bottom;
  final Function? backButtonAction;
  final Color? backgroundColor;
  final Color? titleColor;
  final int fontWeightDelta;

  Toolbar(
      {Key? key,
      this.titleStr = '',
      this.height = 48,
      this.showBack = true,
      this.bottom,
      this.actions = const [],
      this.backButtonAction = null,
      this.backgroundColor = FXColor.main_white,
      this.fontWeightDelta = 0,
      this.titleColor = FXColor.main_black1})
      : super(
            key: key,
            centerTitle: true,
            toolbarHeight: height,
            elevation: 0,
            backgroundColor: backgroundColor,
            title:
                CenterText(titleStr, style: CenterText.title_black.apply(color: titleColor, fontWeightDelta: fontWeightDelta)),
            actions: actions,
            leading: showBack
                ? Builder(builder: (context) {
                    return IconButton(
                        splashColor: Colors.transparent,
                        highlightColor: Colors.transparent,
                        padding: const EdgeInsets.all(6),
                        icon: ImageIcon(AssetImage(ImageUtil.imageFullName('images/icon_back.png')), color: FXColor.black),
                        onPressed: () {
                          backButtonAction?.call();
                          Navigator.maybePop(context);
                        });
                  })
                : null,
            bottom: bottom);
}
